%global pyname python-cloudflare
%global pypi_name cloudflare
%global py3_prefix python%{python3_pkgversion}

%if 0%{?fedora} && 0%{?fedora} >= 30
%bcond_with python2
%else
%bcond_without python2
%endif

Name:           python-%{pypi_name}
Version:        2.3.1
Release:        1%{?dist}
Summary:        Python wrapper for the Cloudflare Client API v4

License:        MIT
URL:            https://pypi.python.org/pypi/%{pypi_name}
Source0:        %{pypi_source}
Source1:        %{pypi_source}.asc
# upstream mentions https://keybase.io/mahtin as canonical source of release
# signing key: https://github.com/cloudflare/python-cloudflare/issues/93
# Key-ID verified via Twitter profile: https://twitter.com/mahtin
Source2:        https://keybase.io/mahtin/pgp_keys.asc?fingerprint=7ea139c40c1c842f9d41aaf94a34925d05172859#/gpg-7ea139c40c1c842f9d41aaf94a34925d05172859.asc
# pypi release does not contain man page:
# https://github.com/cloudflare/python-cloudflare/issues/94
Source3:        https://raw.githubusercontent.com/cloudflare/python-cloudflare/c2224e4fa466ba8372e2f5898fc299b8923c6c73/cli4/cli4.man

# TODO: Remove this once jsonlines is packaged
Patch0:         remove-jsonlines.patch
Patch1:         remove-shebangs.patch
Patch2:         remove-examples.patch

BuildArch:      noarch

%if %{with python2}
BuildRequires:  python2-devel
BuildRequires:  python2-future
BuildRequires:  python2-requests
BuildRequires:  python2-setuptools

%if 0%{?fedora} > 27
BuildRequires:  python2-pyyaml
%else
BuildRequires:  PyYAML
%endif
%endif

BuildRequires:  %{py3_prefix}-devel
BuildRequires:  %{py3_prefix}-future
BuildRequires:  %{py3_prefix}-PyYAML
BuildRequires:  %{py3_prefix}-requests
BuildRequires:  %{py3_prefix}-setuptools

# Used to verify OpenPGP signature
BuildRequires:  gnupg2
BuildRequires:  sed

%description
Python wrapper library for the Cloudflare Client API v4.

%if %{with python2}
%package -n python2-%{pypi_name}
Requires:       python2-future
Requires:       python2-requests

%if 0%{?fedora} > 27
Requires:       python2-pyyaml
%else
Requires:       PyYAML
%endif

Summary:        %{summary}
%{?python_provide:%python_provide python2-%{pypi_name}}

%description -n python2-%{pypi_name}
Python wrapper library for the Cloudflare Client API v4.

This is the Python 2 version of the package.
%endif

%package -n %{py3_prefix}-%{pypi_name}
Requires:       %{py3_prefix}-future
Requires:       %{py3_prefix}-PyYAML
Requires:       %{py3_prefix}-requests

Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n %{py3_prefix}-%{pypi_name}
Python wrapper library for the Cloudflare Client API v4.

This is the Python 3 version of the package.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -p1 -n %{pypi_name}-%{version}
rm -rf *.egg-info
# Remove shebangs
sed -i -e '1!b' -e '\~^#!/usr/bin/env python~d' cli4/*.py

%build
%if %{with python2}
%py2_build
%endif
%py3_build

%install
# Remove examples
rm -rf build/lib/examples

%if %{with python2}
%py2_install
%endif
%py3_install

install -pD %{SOURCE3} %{buildroot}%{_mandir}/man1/cli4.1

%if %{with python2}
%files -n python2-%{pypi_name}
%license LICENSE
%doc README.rst
%{_bindir}/cli4
%doc %attr(0644,root,root) %{_mandir}/man1/cli4.1*
%{python2_sitelib}/cli4
%{python2_sitelib}/CloudFlare
%{python2_sitelib}/cloudflare-%{version}*.egg-info
%endif

%files -n %{py3_prefix}-%{pypi_name}
%license LICENSE
%doc README.rst
%if ! %{with python2}
%{_bindir}/cli4
%doc %attr(0644,root,root) %{_mandir}/man1/cli4.1*
%endif
%{python3_sitelib}/cli4
%{python3_sitelib}/CloudFlare
%{python3_sitelib}/cloudflare-%{version}*.egg-info

%changelog
* Tue Mar 21 2023 Jonathan Wright <jonathan@almalinux.org> - 2.3.1-1
- update to 2.3.1
- rhbz#2180352

* Wed May 06 2020 Felix Schwarz <fschwarz@fedoraproject.org> - 2.3.0-2
- enable GPG verification of sources
- build Python 3 subpackage for EPEL 7

* Mon Jul 01 2019 Eli Young <elyscape@gmail.com> - 2.3.0-1
- Update to 2.3.0 (#1712059)

* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Dec 13 2018 Eli Young <elyscape@gmail.com> - 2.1.0-11
- Remove Python 2 package in Fedora 30+ (#1658535)

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Jul 06 2018 Eli Young <elyscape@gmail.com> - 2.1.0-9
- Simplify example removal

* Fri Jun 29 2018 Eli Young <elyscape@gmail.com> - 2.1.0-8
- Remove unnecessary shebangs

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 2.1.0-7
- Rebuilt for Python 3.7

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 2.1.0-6
- Rebuilt for Python 3.7

* Wed Apr 04 2018 Eli Young <elyscape@gmail.com> - 2.1.0-5
- Fix man page permissions

* Wed Apr 04 2018 Eli Young <elyscape@gmail.com> - 2.1.0-4
- Add cli4 man page

* Wed Apr 04 2018 Eli Young <elyscape@gmail.com> - 2.1.0-3
- Remove example scripts from egg info
- Remove unnecessary shebangs

* Wed Apr 04 2018 Eli Young <elyscape@gmail.com> - 2.1.0-2
- Fix python3 package dependencies (#1563427)

* Tue Mar 27 2018 Eli Young <elyscape@gmail.com> - 2.1.0-1
- Update to 2.1.0 (#1560758)

* Mon Feb 26 2018 Nick Bebout <nb@usi.edu> - 2.0.4-2
- Add python2- prefix where available

* Fri Feb 16 2018 Eli Young <elyscape@gmail.com> - 2.0.4-1
- Initial package (#1546297)
